# *mldrift*

[![Python code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![license: MIT](https://img.shields.io/badge/License-MIT-purple.svg)](LICENSE)

Data drift by ML, for ML.

## Getting started

Coming soon!

## Contributing

No thank you.
